       SUBROUTINE  SO_BBBN ( bulltn, kpos, ipole, clat, clong, nnpts,
     +                       ib1, iret )
C************************************************************************
C*                                                                      *
C* SO_BBBN                                                              *
C*                                                                      *
C* This routine decodes the (B1 B2 B3 nn) group.  The B1 B2 B3 number   *
C* designates a 10 x 10 degree square in the geographical grid formed   *
C* by the intersection of two meridians and two parallels of latitude.  *
C* A corner of the square is chosen as a latitude/longitude reference   *
C* point for determining the lat/long locations in the square of the    *
C* observational data.  nn gives the number of observational points in  *
C* the square.  An explanation of the B1 B2 B3 number is given in the   *
C* WMO Manual on Codes.                                                 *
C*                                                                      *
C* SO_BBBN( BULLTN, KPOS, IPOLE, CLAT, CLONG, NNPTS, IB1, IRET )        *
C*                                                                      *
C* Input parameters:                                                    *
C*      BULLTN         CHAR*             Bulletin array                 *
C*					                                *
C* Input and Output parameters:                                         *
C*      KPOS           INTEGER           On input, points to start of   *
C*                                       BBBnn group; on output, points *
C*                                       to start of lat/long group     *
C*                                       following BBBnn group          *
C*					                                *
C* Output parameters:                                                   *
C*      IPOLE          INTEGER           Flag value.                    *
C*                                        0 = point other than north or *
C*                                            south pole                *
C*                                        1 = north pole                *
C*                                        2 = south pole                *
C*      CLAT           REAL              The latitude of the reference  *
C*                                       point of the BBB square        *
C*      CLONG          REAL              The longitude of the reference *
C*                                       point of the BBB square        *
C*      NNPTS          INTEGER           The number of data points in   *
C*                                       10 deg (BBB) square            *
C*      IB1            INTEGER           The octant of the globe        *
C*                                       (WMO Code Table 3300)          *
C*	IRET	       INTEGER           Return code                    *
C*                                        0 = normal return             *
C*                                        1 = reject bulletin           *
C*                                                                      *
C**                                                                     *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP       3/98  Cleaned up code                          *
C************************************************************************
        INCLUDE         'socmn.cmn'
C*
        CHARACTER*(*)   bulltn
C*
        CHARACTER       fld2*2,   fld1*1
C------------------------------------------------------------------------
        iret = 0
        ipt = kpos
        kpos = kpos + 6
C
C*      Get number of points in 10 x 10 degree square.
C
        fld2 = bulltn ( ipt+3:ipt+4 )
        CALL  ST_INTG ( fld2, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            nnpts = ival
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get the octant of the globe  (B1).
C
        fld1 = bulltn ( ipt:ipt )
        CALL  ST_INTG ( fld1, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ib1 = ival
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get the B2 (latitude) digit.
C
        ipt = ipt + 1
        fld1 = bulltn ( ipt:ipt )
        CALL  ST_INTG ( fld1, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ib2 = ival
            xib2 = ib2
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get the B3 (longitude) digit.
C
        ipt = ipt + 1
        fld1 = bulltn ( ipt:ipt )
        CALL  ST_INTG ( fld1, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ib3 = ival
            xib3 = ib3
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Determine the latitude/longitude coordinates of
C*      the corner of the B1 B2 B3 square.
C
        ipole = 0
        clat = 10 * xib2
C
C*      Special cases
C
        IF ( ib1 .eq. 1 .and. ib2 .eq. 9 .and. ib3 .eq. 0 ) THEN
C
C*          North Pole
C
            clat = 90.
            clong = 0.0
            ipole = 1
            RETURN
        END IF
C
        IF ( ib1 .eq. 6 .and. ib2 .eq. 9 .and. ib3 .eq. 0 ) THEN
C
C*          South Pole
C
            clat = -90.
            clong = 0.0
            ipole = 2
            RETURN
        END IF
C
        IF ( ib1 .eq. 1 .and. ib3 .eq. 8 ) THEN
C
C*          180 deg meridian  (Northern Hemisphere)
C
            clong = 180.
            RETURN
        END IF
C
        IF ( ib1 .eq. 6 .and. ib3 .eq. 8 ) THEN
C
C*          180 deg meridian  (Southern Hemisphere)
C
            clat = - clat
            clong = 180.
            RETURN
        END IF
C
        IF ( ib1 .eq. 0 ) THEN
            clong = -10. * xib3
          ELSE IF ( ib1 .eq. 1 .and. ib3 .eq. 9 ) THEN
            clong = -90.
          ELSE IF ( ib1 .eq. 1 ) THEN
            clong = -100. + (-10. * xib3)
          ELSE IF ( ib1 .eq. 2 .and. ib3 .eq. 9 ) THEN
            clong = 90.
          ELSE IF ( ib1 .eq. 2 ) THEN
            clong = 100. + (10. * xib3)
          ELSE IF ( ib1 .eq. 3 ) THEN
            clong = 10. * xib3
          ELSE IF ( ib1 .eq. 5 ) THEN
            clat = - clat
            clong = -10. * xib3
          ELSE IF ( ib1 .eq. 6 .and. ib3 .eq. 9 ) THEN
            clat = - clat
            clong = -90.
          ELSE IF ( ib1 .eq. 6 ) THEN
            clat = - clat
            clong = -100. + (-10. * xib3)
          ELSE IF ( ib1 .eq. 7 .and. ib3 .eq. 9 ) THEN
            clat = - clat
            clong = 90.
          ELSE IF ( ib1 .eq. 7 ) THEN
            clat = - clat
            clong = 100. + (10. * xib3 )
          ELSE IF ( ib1 .eq. 8 ) THEN
            clat = - clat
            clong = 10. * xib3
          ELSE
            iret = 1
        END IF
C*
	RETURN
	END
