        SUBROUTINE  SO_SEC1( bulltn, ipt, iret )
C************************************************************************
C*                                                                      *
C* SO_SEC1                                                              *
C*                                                                      *
C* This subroutine decodes the groups in section 1 of the bulletin.     *
C* These groups contain the GMT observational time, the units of the    *
C* wind speed, the method by which the winds are determined, and the    *
C* country or agency operating the satellite.                           *
C*                                                                      *
C* SO_SEC1  ( BULLTN, IPT, IRET )                                       *
C*                                                                      *
C* Input parameters:                                                    *
C*      BULLTN          CHAR*           Bulletin array                  *
C*                                                                      *
C* Input and Output parameters:                                         *
C*      IPT             INTEGER         On input, points to first Y in  *
C*                                      group YYXX; on output, points   *
C*                                      to last / in group III//        *
C* Output parameters:                                                   *
C*      RIVALS(IRTIWM)  REAL            Type of instrumentation for	*
C*					wind measurement		*
C*					(WMO BUFR Table 0 02 002)	*
C*      RIVALS(IRSWCM)  REAL            Satellite derived wind		*
C*                                      computation method		*
C*					(WMO Code Table 4639)		*
C*      RIVALS(IRSAID)  REAL            Satellite identifier            *
C*      CIVALS(ICSANA)  CHAR*           Indicator figure for satellite  *
C*                                      name                            *
C*      RIVALS(IRYDGT)  REAL            Report year of observation      *
C*                                      (units digit only)              *
C*      RIVALS(IRMNTH)  REAL            Report month of observation     *
C*      RIVALS(IRDAYS)  REAL            Report day of observation       *
C*      RIVALS(IRHOUR)  REAL            Report hour of observation      *
C*      RIVALS(IRMINU)  REAL            Report minute of observation    *
C*      ICHG            INTEGER         Satellite flag ID.              *
C*                                       0 = Satellite ID not in sec 1  *
C*                                       1 = Satellite ID in sec 1      *
C*      ICNTRY          INTEGER         WMO Code Table 1761 figure.     *
C*                                      Indicates country operating     *
C*                                      satellite.                      *
C*      IMNDAY          INTEGER         Day of month of observation     *
C*                                      of data                         *
C*      IHOUR           INTEGER         Hour of observation of data     *
C*      IMINS           INTEGER         Minutes of hour of obs of data  *
C*      IRPTDT (5)      INTEGER         Report date-time                *
C*                                      (YYYY, MM, DD, HH, MM)          *
C*      IRET            INTEGER         Return code                     *
C*                                       0 = normal return              *
C*                                       1 = problems                   *
C*                                                                      *
C**                                                                     *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP      10/97  Added logic to decode the new I6I6I6//   *
C*                             and F3F3F3F4F4F4 groups                  *
C* R. Hollern/NCEP       3/98  Changed interface and cleaned up code    *
C* R. Hollern/NCEP	10/00  Added date/time data to interface array  *
C* J. Ator/NCEP		01/02  CMCM -> SWCM, SUWS -> TIWM		*
C* J. Ator/NCEP		01/02  Remove methwd and iuwind from /COMMON/	*
C* R. Hollern/NCEP	05/03  Added logic to get GOES-9 satob data from*
C*			       JMA					*
C* C. Caruso Magee/NCEP 01/06  Save only units digit of year here.      *
C************************************************************************
        INCLUDE  'socmn.cmn'
C*
        CHARACTER*(*)   bulltn
C*
        CHARACTER   fld3*3,   fld2*2,   ispace*1,   fld1*1
C*
        LOGICAL  more
C*
        DATA  ispace / ' ' /
C------------------------------------------------------------------------
        iret = 0
        more = .TRUE.
        jp = 0
C
C*      Skip over YYXX string.
C
        DO  WHILE ( more )
C
            ipt = ipt + 1
C
            IF ( bulltn ( ipt:ipt ) .eq. ispace ) THEN
                more = .false.
            END IF
C
        END DO
C
C*      Decode the YYMMJ group.
C
C*      Get the day of the month of report time -- YY.
C
        ipt = ipt + 1
C
        fld2 = bulltn ( ipt:ipt+1 )
        CALL  ST_INTG ( fld2, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ipt = ipt + 2
            IF ( ival .gt. 50 ) THEN
C
C*              YY is also used to indicate the unit of wind
C*              speed.  If ival greater than 50, then units of
C*              wind speed are in knots; otherwise, in m/sec.
C
                rivals ( irtiwm ) = 4.
                ival = ival - 50
              ELSE
                rivals ( irtiwm ) = 0.
            END IF
C
            IF ( ival .gt. 0 .and. ival .lt. 32 ) THEN
                imnday = ival
                irptdt(3) = ival
                rivals ( irdays ) = FLOAT ( ival )
              ELSE
                na = ipt - 3
                nb = ipt + 5
                CALL DC_WLOG ( 2, 'SO', 3, bulltn(na:nb), ierr )
                iret = 1
                RETURN
            END IF
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get month of report time -- MM.
C
        fld2 = bulltn ( ipt:ipt+1 )
        CALL  ST_INTG ( fld2, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ipt = ipt + 2
C
            IF ( ival .gt. 0 .and. ival .lt. 13 ) THEN
                imonth = ival
                irptdt(2) = ival
                rivals ( irmnth ) = FLOAT ( ival )
              ELSE
                na = ipt - 3
                nb = ipt + 5
                CALL DC_WLOG ( 2, 'SO', 3, bulltn(na:nb), ierr )
                iret = 1
                RETURN
            END IF
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get year of report time -- J (units digit of year only).
C
        fld1 = bulltn ( ipt:ipt )
        CALL  ST_INTG ( fld1, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ipt = ipt + 2
            rivals ( irydgt ) =  FLOAT ( ival )
          ELSE
            na = ipt - 3
            nb = ipt + 5
            CALL DC_WLOG ( 2, 'SO', 3, bulltn(na:nb), ierr )
            iret = 1
            RETURN
        END IF
C
C*      Decode the GGggw(i) group.
C
C*      Get hour of report time -- GG.
C
        fld2 = bulltn ( ipt:ipt+1 )
        CALL  ST_INTG ( fld2, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ipt = ipt + 2
            IF ( ival .ge. 0 .and. ival .lt. 24 ) THEN
                ihour = ival
                irptdt ( 4 ) = ival
                rivals ( irhour ) =  FLOAT ( ival )
              ELSE
                na = ipt - 3
                nb = ipt + 5
                CALL DC_WLOG ( 2, 'SO', 3, bulltn(na:nb), ierr )
                iret = 1
                RETURN
            END IF
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Get minutes of hour of report time -- gg.
C
        fld2 = bulltn ( ipt:ipt+1 )
        CALL  ST_INTG ( fld2, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ipt = ipt + 2
            IF ( ival .ge. 0 .and. ival .lt. 60 ) THEN
                imins = ival
                irptdt ( 5 ) = ival
                rivals ( irminu ) =  FLOAT ( ival )
              ELSE
                na = ipt - 3
                nb = ipt + 5
                CALL DC_WLOG ( 2, 'SO', 3, bulltn(na:nb), ierr )
                iret = 1
                RETURN
            END IF
          ELSE
            iret = 1
            RETURN
        END IF
C
C*      Method by which satellite winds were determined -- w(i).  
C
        fld1 = bulltn ( ipt:ipt )
        CALL  ST_INTG ( fld1, ival, ier )   
        IF ( ier .eq. 0 ) THEN
            ipt = ipt + 2
            rivals ( irswcm ) = REAL ( ival )
          ELSE 
            iret = 1
            RETURN
        END IF
C
C*      On November 5, 1997, Section 1 will change as follows:
C
C*      (I1 I2 I2 //) will be replaced by (I6 I6 I6 //)
C*      (F3 F3 F3 F4 F4)
C
        IF ( bulltn ( ipt+9:ipt+9 ) .eq. ' ' ) THEN
            ichg = 0
          ELSE 
            ichg = 1
        END IF
C
        IF ( ichg .eq. 1 ) THEN
C
C*          Get the satellite identifier.
C
            fld3 = bulltn ( ipt:ipt+2 )
            ipt = ipt + 6
C
            CALL  ST_INTG ( fld3, ival, ier )   
            IF ( ier .eq. 0 ) THEN
                rivals ( irsaid ) = REAL ( ival )
C
                icntry = -1
                IF ( ival .ge. 1 .AND. ival .le. 99 ) THEN
C
C*                  European Union
C
                    icntry = 0
                  ELSE IF ( ival .ge. 100 .AND. ival .le. 199 ) THEN
C
C*                  Japan
C
                    icntry = 1
                  ELSE IF ( ival .ge. 400 .AND. ival .le. 499 ) THEN
C
C*                  India
C
                    icntry = 4
                END IF
              ELSE 
                iret = 1
                RETURN
            END IF
C
C*          Get the ID of the generating center.
C
            fld3 = bulltn ( ipt:ipt+2 )
C
C*          Find next space to define ipt.
C
            iflg = 0
C
            DO i = ipt+3,ipt+6
                IF ( bulltn ( i:i ) .eq. ' ' ) THEN
                    ipt = i + 1
                    iflg = 1
                END IF
            END DO
C
           IF ( iflg .eq. 0 ) THEN
               iret = 1
               RETURN
           END IF
C
           CALL  ST_INTG( fld3, ival, ier )   
           IF ( ier .eq. 0 ) THEN
                rivals ( irgenc ) = REAL ( ival )
C 
C*              On May 22, 2003 JMA will no longer get the satob
C*              satellite data from GMS-5, but from the U.S.
C*              GOES-9 satellite.
C
                IF ( icntry .eq. -1 .and. ival .eq. 34 ) THEN
                     icntry = 1
                END IF
           ELSE 
              iret = 1
              RETURN
           END IF
        END IF
C
        IF ( ichg .eq. 0 ) THEN
C
C*          Get code figure of country that operates satellite.
C
            fld1 = bulltn ( ipt:ipt )
            ipt = ipt + 1
            CALL  ST_INTG ( fld1, ival, ier )   
            IF ( ier .eq. 0 ) THEN
                icntry = ival
                rivals ( irsaco ) = REAL ( ival )
              ELSE 
                iret = 1
                RETURN
            END IF
C
C*          Get indicator figure for satellite name.
C
            fld2 = bulltn ( ipt:ipt+1 )
            ipt = ipt + 3
            civals ( icsana ) = fld2
C
        END IF
C*
	RETURN
	END
