       SUBROUTINE  SO_SEC3 ( lenb, bulltn, kpos, iret )
C************************************************************************
C*                                                                      *
C* SO_SEC3                                                              *
C*                                                                      *
C* This subroutine calls the routines to decode the groups in section 3 *
C* of the WMO FM 88 SATOB bulletin.  This section contains winds        *
C* computed from cloud movement or water-vapour motion at specified     *
C* pressure levels.  The number of data points varies from bulletin to  *
C* bulletin.                                                            *
C*                                                                      *
C* SO_SEC3 ( LENB, BULLTN, KPOS, IRET )                                 *
C*                                                                      *
C* Input parameters:                                                    *
C*                                                                      *
C*      LENB            INTEGER         Bulletin length in bytes        *
C*      BULLTN          CHAR*           Bulletin array                  *
C*      KPOS            INTEGER         Pointer set to start of the     *
C*                                      first BBBnn group in bulltin    *
C*      IOBSPT          INTEGER         Index value for pointer arrays  *
C*					                                *
C* Output parameters:                                                   *
C*      RIVALS(IRNPTS)  REAL            Number of data points           *
C*	IRET	        INTEGER         Return code                     *
C*				   	 0 = normal return              *
C*                                       1 = reject bulletin            *
C*                                                                      *
C**                                                                     *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP       3/98  Changed interface and cleaned up code    *
C************************************************************************
        INCLUDE    'socmn.cmn'
C*
        CHARACTER*(*)    bulltn
C*
        LOGICAL  again
C------------------------------------------------------------------------
        iret = 0
        ipt = kpos
        iobspt = 0
        numpts = 0
        again = .true.
C
        DO WHILE ( again )
C
C*          Get the latitude/longitude cordinates of the B1 B2 B3
C*          square and the number of observational data points in square
C
            CALL SO_BBBN( bulltn, kpos, ipole, clat, clong, nnpts,
     +                    ib1, kret )
C
            IF ( kret .ne. 0 ) THEN
                iret = 1
                RETURN
            END IF 
C
            numpts = iobspt + nnpts
C
C*          Do not exceed 900 points, since  BUFR message limited to
C*          10000 bytes.
C
            IF ( numpts .ge. 900 ) THEN
                nnpts = nnpts - ( numpts - 900 )
                again = .false.
            END IF
C
            IF ( ipole .ne. 0 ) THEN
C
C*              Skip polar data groups, since geostationary satellite
C*              should not send these groups.        
C
                kpos = kpos + ( 12*nnpts )
C
C*              Skip following DO loop.
C
                nnpts = 0
            END IF
C
            DO i = 1,nnpts
C
C*              Check if missing groups at end of bulletin.
C
                IF ( (kpos + 8) .gt. lenb ) THEN
                    rivals ( irnpts ) = iobspt
                    RETURN
                END IF
C
                iobspt = iobspt + 1
C
C*              Decode the (Ula Ula Pe Pe /) group.
C
                CALL SO_UUPP( bulltn, kpos, ib1, clat, clong, ipole,
     +                        kret )
C
C*              Decode the ddfff group.
C
                CALL SO_DDFF( bulltn, kpos, kret )
C
            END DO
C
            IF ( (kpos + 10) .gt. lenb ) THEN
               again = .false.
            END IF
        END DO
C
C*      Number of data points.
C
        IF ( iobspt  .gt. 0 ) THEN
            rivals ( irnpts ) = iobspt
        END IF 
C*
	RETURN
	END
