       SUBROUTINE  SO_UUUU ( bulltn, ib1, clat, clong, kpos, xlatln,
     +                       iret )
C************************************************************************
C*                                                                      *
C* SO_UUUU                                                              *
C*                                                                      *
C* This routine decodes the (ULa ULo ULa ULo /) groups in section 2.    *
C* The ULa is the units digit in the reported latitude and ULo is the   *
C* units digit in the reported longitude.  The two pairs ULa ULo refer  *
C* to two different locations in the B1 B2 B3 square.                   *
C*                                                                      *
C*                                                                      *
C* SO_UUUU ( BULLTN, IB1, CLAT, CLONG, KPOS, XLATLN, IRET )             *
C*                                                                      *
C* Input parameters :                                                   *
C*      BULLTN          CHAR*           Bulletin array                  *
C*      IB1             INTEGER         The octant of the globe         *
C*      CLAT            REAL            The latitude of the reference   *
C*                                      point of the BBB square         *
C*      CLONG           REAL            The longitude of the reference  *
C*                                      point of the BBB square         *
C* Input and output parameters:                                         *
C*      KPOS            INTEGER         On input, points to start of    *
C*                                      UUUU/ group; on ouput, points   *
C*                                      to start of the following       *
C*                                      ddfff group                     *
C*                                                                      *
C* Output parameters:                                                   *
C*      XLATLN         REAL             Array holding the lat/long      *
C*                                      positions of the two current    *
C*                                      data points                     *
C*	IRET	       INTEGER          Return code                     *
C*				   	 0 = normal return              *
C*                                       1 = reject bulletin            *
C*                                                                      *
C**                                                                     *
C* Log:                                                                 *
C* R. Hollern/NCEP      10/96                                           *
C* R. Hollern/NCEP      12/96  Replaced ST_C2R with ST_INTG             *
C* R. Hollern/NCEP       3/98  Cleaned up code                          *
C************************************************************************
        INCLUDE    'socmn.cmn'
C*
        CHARACTER*(*)   bulltn*(*)
        REAL  xlatln(2,2)
C*
        CHARACTER   fld1*1
C*
        DATA  xmiss / -999. /
C------------------------------------------------------------------------
        iret = 0
        ipt = kpos
        kpos = kpos + 6
C
C*      Determine the sign of the lat/long position.
C
        IF ( ib1 .eq. 0 .or. ib1 .eq. 1 ) THEN
            sgnla = 1.0
            sgnlo = -1.0
          ELSE IF ( ib1 .eq. 2 .or. ib1 .eq. 3 ) THEN
            sgnla = 1.0
            sgnlo = 1.0
          ELSE IF ( ib1 .eq. 5 .or. ib1 .eq. 6 ) THEN
            sgnla = -1.0
            sgnlo = -1.0
          ELSE IF ( ib1 .eq. 7 .or. ib1 .eq. 8 ) THEN
            sgnla = -1.0
            sgnlo = 1.0
          ELSE
            iret = 1
            RETURN
        END IF
C
        IF ( clong .eq. 180. ) THEN
C 
C*          180 deg meridian.
C
            sgnlo = 1.0
        END IF
C
C*      Initialize xlatln to all missing.
C
        DO ii = 1,2
            xlatln ( ii,1 ) = xmiss
            xlatln ( ii,2 ) = xmiss
        END DO
C
        DO ii = 1,2
C
C*          Get the units digit in the reported latitude.
C
            fld1 = bulltn ( ipt:ipt )
            ipt = ipt + 1
            CALL ST_INTG ( fld1, ival, ier )
            IF ( ier .eq. 0 ) THEN
                rval = FLOAT ( ival )
                rval = sgnla * rval
                xlatln ( ii,1 ) = clat + rval
            END IF
C
C*          Get the units digit in the reported longitude.
C
            fld1 = bulltn ( ipt:ipt )
            ipt = ipt + 1
            CALL ST_INTG ( fld1, ival, ier )
            IF ( ier .eq. 0 ) THEN
                rval = FLOAT ( ival )
                rval = sgnlo * rval
                xlatln ( ii,2 ) = clong + rval
            END IF
C
        END DO
C*
	RETURN
	END
